@@ -160,6 +160,16 @@ GET_COMMANDS = (
         func=lazy_load_command("thabala_cli.commands.get_command.health"),
         args=(ARG_PROFILE,),
     ),
+    ActionCommand(
+        name="network-policy",
+        help="Get network policy rules",
+        func=lazy_load_command("thabala_cli.commands.get_command.network_policy"),
+        args=(
+            ARG_PROFILE,
+            ARG_LIMIT,
+            ARG_OFFSET,
+        ),
+    ),
     ActionCommand(
         name="service-instances",
         help="Get Thabala service instances",
