@@ -14,6 +14,7 @@ from thabala_cli.commands.utils.auth_webbrowser import AuthByWebBrowser
 from thabala_cli.commands.utils.profile import EXTERNAL_BROWSER_AUTHENTICATOR
 from thabala_cli.commands.utils.profile import PASSWORD_AUTHENTICATOR
 from thabala_cli.exceptions import ThabalaCliApiException
+from thabala_cli.exceptions import ThabalaCliInfraCodeException
 from thabala_cli.exceptions import ThabalaOperationException
 from thabala_cli.utils.helpers import raise_thabala_cli_api_exc
 
@@ -88,7 +89,10 @@ class ApiClient:
             )
             response.raise_for_status()
         except requests.exceptions.HTTPError as err:
-            raise_thabala_cli_api_exc(err, response.json())
+            try:
+                raise_thabala_cli_api_exc(err, response.json())
+            except json.decoder.JSONDecodeError:
+                raise_thabala_cli_api_exc(err)
         except Exception as err:
             raise_thabala_cli_api_exc(err)
 
@@ -247,8 +251,16 @@ class ApiClient:
         )
         print(ApiClient.pretty_json(response_json))
 
-    def get_infra(self, kind):
+    def get_infra(self, kind, valid_kinds=None):
         """Get infrastructure as a code of the Thabala account"""
+        if not valid_kinds:
+            valid_kinds = []
+
+        if kind and kind not in valid_kinds:
+            raise ThabalaCliInfraCodeException(
+                f"Invalid infrastructure resource kind: {kind}. Valid kinds are {valid_kinds}"
+            )
+
         response_json = self._login_and_request(f"{self.api_base_url}/infra")
         kinds = []
         if kind:
@@ -277,6 +289,17 @@ class ApiClient:
 
         return response_json
 
+    def get_network_policy(self, limit: int, offset: int):
+        """Get network policy rules"""
+        params = {
+            "limit": f"limit={limit}" if limit else "",
+            "offset": f"offset={offset}" if offset else "",
+        }
+        endpoint_url = f"network-policies?{params['limit']}&{params['offset']}"
+
+        response_json = self._login_and_request(f"{self.api_base_url}/{endpoint_url}")
+        print(ApiClient.pretty_json(response_json))
+
     def get_version(self):
         """Get version of Thabala account"""
         response_json = self._login_and_request(
