@@ -4,12 +4,11 @@ import yaml
 
 from thabala_cli.commands.utils.api_client import ApiClient
 from thabala_cli.exceptions import ThabalaCliInfraCodeException
-from thabala_cli.utils.helpers import raise_thabala_cli_api_exc
 
 log = logging.getLogger(__name__)
 
 
-VALID_KINDS = ["Authenticator", "Users", "ServiceInstance"]
+VALID_KINDS = ["Authenticator", "NetworkPolicy", "Users", "ServiceInstance"]
 
 
 class InfraCode:
@@ -18,6 +17,7 @@ class InfraCode:
 
         InfraCode.kind_appliers = {
             "Authenticator": self._apply_authenticator,
+            "NetworkPolicy": self._apply_network_policy,
             "Users": self._apply_users,
             "ServiceInstance": self._apply_service_instance,
         }
@@ -29,6 +29,10 @@ class InfraCode:
         log.info(f"Applying authenticator...")
         return self.api_client.post_infra(resource)
 
+    def _apply_network_policy(self, resource):
+        log.info(f"Applying network policy...")
+        return self.api_client.post_infra(resource)
+
     def _apply_users(self, resource):
         log.info(f"Applying users...")
         return self.api_client.post_infra(resource)
