@@ -487,7 +487,7 @@ def initialize_config():
     """
     global THABALA_HOME
 
-    default_config = _parameterized_config_from_template("default_thabala_cli.cfg")
+    default_config = _parameterized_config_from_template("default_cli.cfg")
 
     conf = ThabalaCliConfigParser(default_config=default_config)
 
@@ -509,7 +509,8 @@ def initialize_config():
             pathlib.Path(THABALA_HOME).mkdir(parents=True, exist_ok=True)
 
             with open(THABALA_CLI_CONFIG, "w") as file:
-                file.write(default_config)
+                cfg = _parameterized_config_from_template("default_cli_user.cfg")
+                file.write(cfg)
 
         log.info("Reading the config from %s", THABALA_CLI_CONFIG)
 
